Polski Związek Działkowców - Błąd 404 - nie znaleziono strony
Author: Esencja Studio @ www.esencja-studio.pl
Description: Polski Związek Działkowców

Rodzina
Zdrowie
Ekologia
Edukacja
Wypoczynek

# Błąd 404 - nie znaleziono strony

## Komunikat KR PZD w sprawie wydania i dystrybucji Statutu PZD, Regulaminu ROD i innych dokumentów - 02.12.2015

Krajowa Rada PZD informuje, że Prezydium Krajowej Rady w ostatnim czasie podjęło kilka decyzji o wydaniu pozycji, które ułatwią funkcjonowanie i właściwe zarządzanie organom PZD, a działkowcom ułatwią korzystanie z prawa w PZD. Są to:

1. Statut PZD uchwalony na XII Krajowym Zjeździe Delegatów PZD w dniu 2 lipca 2015 roku, zarejestrowany w KRS dnia 9 września 2015 roku. Wydrukowano go w nakładzie 60 000 egzemplarzy, a koszty wydania i dystrybucji pokrywa KR PZD i okręgi po 50%. Statut PZD trafił już do zarządów ROD.
2. Regulamin ROD uchwalony przez Krajową Radę w dniu 1 października 2015 roku. Regulamin ROD bezpłatnie otrzyma każdy działkowiec w ROD, niezależnie od tego czy jest członkiem PZD, czy też nie. Został wydrukowany w nakładzie 1 000 000 egzemplarzy, a koszty wydania i dystrybucji pokryją po połowie KR PZD oraz okręgi ze środków budżetowych. Regulamin ROD zostanie przekazany do okręgów, skąd zarządy ROD powinny go odbierać dla wszystkich działkowców w swoim ROD.
3. Zawiadomienia na walne zebrania sprawozdawcze w ROD w roku 2016 w formie karty pocztowej z przeznaczeniem dla każdego członka PZD. Koszty wydruku i dystrybucji do okręgów 900 000 sztuk zawiadomień pokryje Krajowa Rada PZD ze środków budżetowych. Zarządy ROD odbierają zawiadomienia dla członków PZD ze swojego ROD z okręgów.
4. Regulamin Komisji Rewizyjnych PZD uchwalony przez Krajową Komisję Rewizyjną w dniu 12 listopada 2015 roku. Regulamin jest przeznaczony dla komisji rewizyjnych na wszystkich szczeblach, zarządów ROD i okręgów. Został on wydrukowany w nakładzie 22 000 egzemplarzy, a koszty pokryje KR PZD.
5. III wydanie książki „Prawo w PZD” z aktualnymi przepisami prawnymi. Książka będzie zawierała: ustawę z dnia 13 grudnia 2013 roku o rodzinnych ogrodach działkowych, statut PZD uchwalony na XII Krajowym Zjeździe Delegatów PZD w dniu 2 lipca 2015 r., regulamin ROD uchwalony przez Krajową Radę PZD w dniu 1 października 2015 r., Regulamin Komisji Rewizyjnych uchwalony w dniu 12 listopada 2015 roku, wyciągi ze specustaw i innych regulujących sprawy dotyczące funkcjonowania rodzinnych ogrodów działkowych. „Prawo w PZD” będzie przeznaczone dla zarządów ROD, komisji rewizyjnych, okręgowych zarządów i jednostki krajowej. Nakład 10 000 egzemplarzy. Koszty druku i dystrybucji pokryje KR PZD ze środków budżetowych.

Krajowa Rada

Polskiego Związku Działkowców

Warszawa, dnia 1 grudnia 2015 roku

Powrót

### Powiązane artykuły

### Losowe zdjęcie z Galerii

### Popularne artykuły

Twoja działka
czeka na Ciebie

Copyright © 2015 Polski Związek Działkowców All rights reserved.

made by Esencja Studio